@@ -1,4 +1,19 @@
-__version__ = '0.10.0'
+__version__ = '0.11.0'
+version = __version__
+
+DEBUG = False
+
+import logging
+
+try:
+    from logging import NullHandler
+except ImportError:
+    # Python 2.6 does not have a NullHandler
+    class NullHandler(logging.Handler):
+        def emit(self, record):
+            pass
+
+logging.getLogger('rabbitpy').addHandler(NullHandler())
 
 from rabbitpy.connection import Connection
 from rabbitpy.exchange import Exchange
@@ -15,15 +30,3 @@ from rabbitpy.simple import create_direct_exchange
 from rabbitpy.simple import create_fanout_exchange
 from rabbitpy.simple import create_topic_exchange
 from rabbitpy.simple import delete_exchange
-
-import logging
-
-try:
-    from logging import NullHandler
-except ImportError:
-    # Python 2.6 does not have a NullHandler
-    class NullHandler(logging.Handler):
-        def emit(self, record):
-            pass
-
-logging.getLogger('rabbitpy').addHandler(NullHandler())
